/*
File: ColorMeterDialog.java
Displays a color using sliders to adjust red, green, and blue
components of RGB values.
*/

import BreezySwing.GBFrame;
import BreezySwing.GBDialog;
import BreezySwing.GBPanel; 
import javax.swing.JLabel;
import javax.swing.JSlider;
import javax.swing.JButton;
import java.awt.Color;

public class ColorMeterDialog extends GBDialog{

    private JLabel redLbl = addLabel("Red",       1,1,1,1);
    private JLabel greenLbl = addLabel("Green",   2,1,1,1);
    private JLabel blueLbl = addLabel("Blue",     3,1,1,1);
    private JSlider redSlider = addSlider(        1,2,1,1);
    private JSlider greenSlider = addSlider(      2,2,1,1);
    private JSlider blueSlider = addSlider(       3,2,1,1);
    private GBPanel colorPanel = addPanel(        1,3,1,4);
    JButton okBtn = addButton("OK",               4,1,1,1);
    JButton cancelBtn = addButton("Cancel",       4,2,1,1);

    private Color color;  // The currently selected color

    public ColorMeterDialog(GBFrame parent, Color color){
        super(parent);
        this.color = color;
        initSlider(redSlider, color.getRed());
        initSlider(greenSlider, color.getGreen());
        initSlider(blueSlider, color.getBlue());
        colorPanel.setBackground(color);
        setTitle("Color Meter");
        setSize(400, 200);
    }

    private void initSlider(JSlider slider, int value){
        slider.setPaintTicks(true);
        slider.setPaintTrack(true);
        slider.setMajorTickSpacing(16);
        slider.setMinimum(0);
        slider.setMaximum(255);
        slider.setValue(value);
    }

    public void sliderChanged(JSlider slider){
        int red = redSlider.getValue();
        int blue = blueSlider.getValue();
        int green = greenSlider.getValue();
        color = new Color(red, green, blue);
        colorPanel.setBackground(color);
        if (slider == redSlider){
             redLbl.setText("Red is " + red);
             redLbl.setForeground(new Color(red, 0, 0));
        }
        else if (slider == greenSlider){
             greenLbl.setText("Green is " + green);
             greenLbl.setForeground(new Color(0, green, 0));
        }
        else{
             blueLbl.setText("Blue is " + blue);
             blueLbl.setForeground(new Color(0, 0, blue));
        }
    }

    public void buttonClicked(JButton button){
        if (button == okBtn)
            setDlgCloseIndicator("OK");
        dispose();
    }

    public Color getColor(){
        return color;
    }
}