/*
File: PanelDemo3.java
Allows the user to draw ovals and rectangles with given
positions, dimensions, and colors.
*/

import BreezySwing.GBFrame;
import BreezySwing.GBPanel; 
import javax.swing.JButton;
import javax.swing.JLabel;
import javax.swing.JRadioButton;
import javax.swing.ButtonGroup;
import BreezySwing.IntegerField;
import java.awt.Color;

public class PanelDemo3 extends GBFrame{

    private ExamplePanel2 canvas = new ExamplePanel2();
 
    private JLabel xLbl = addLabel("X",                     1,1,1,1);
    private JLabel yLbl = addLabel("Y",                     2,1,1,1);
    private JLabel wLbl = addLabel("Width",                 3,1,1,1);
    private JLabel hLbl = addLabel("Height",                4,1,1,1);
    private JLabel cLbl = addLabel("Color",                 5,1,1,1);
    private IntegerField xFld = addIntegerField(0,          1,2,1,1);
    private IntegerField yFld = addIntegerField(0,          2,2,1,1);
    private IntegerField wFld = addIntegerField(0,          3,2,1,1);
    private IntegerField hFld = addIntegerField(0,          4,2,1,1);
    private GBPanel colorPanel = addPanel(                  5,2,1,1);
    private JRadioButton oBtn = addRadioButton("Oval",      6,1,1,1);
    private JRadioButton rBtn = addRadioButton("Rectangle", 7,1,1,1);
    private JButton colorBtn = addButton("Choose Color",    6,2,1,1);    
    private JButton drawBtn = addButton("Draw",             7,2,1,1);
    private JButton clearBtn = addButton("Erase",           8,2,1,1);
    private GBPanel panel = addPanel(canvas,                1,3,1,8);

    public PanelDemo3(){
        ButtonGroup bg = new ButtonGroup();
        bg.add(oBtn);
        bg.add(rBtn);
        oBtn.setSelected(true);
        colorPanel.setBackground(Color.red);
        setTitle("Panel Demo 3");
        setSize(500, 300);
        setVisible(true);
    }

    public void buttonClicked(JButton button){
        if (button == colorBtn)
            chooseColor();
        else if (button == drawBtn)
            drawShape();
        else
            canvas.erase();
    }

    private void chooseColor(){
        ColorMeterDialog dlg = 
            new ColorMeterDialog(this, colorPanel.getBackground());
        dlg.setVisible(true);
        if (dlg.getDlgCloseIndicator().equals("OK"))
            colorPanel.setBackground(dlg.getColor());
    }

    private void drawShape(){
        // Draws an oval or rectangle with the current settings.
        int x = xFld.getNumber();
        int y = yFld.getNumber();
        int w = wFld.getNumber();
        int h = hFld.getNumber();
        Color c = colorPanel.getBackground();
        Shape shape;
        if (oBtn.isSelected())
            shape = new Oval(x, y, w, h, c);
        else
            shape = new Rectangle(x, y, w, h, c);
        canvas.draw(shape);
    }
     
    public static void main(String[] args){
        GBFrame theGUI = new PanelDemo3();
    }
}