/*
File: ExamplePanel4.java
Represents a drawing area for drawing shapes
with the mouse.
*/

import BreezySwing.GBPanel; 
import java.awt.Graphics;
import java.awt.Color;
import java.util.List;
import java.util.ArrayList;
import java.util.Random;

public class ExamplePanel4 extends GBPanel{

    private List<Shape> shapeList = new ArrayList<Shape>();
    private int x, y;
    private Random gen = new Random();
    private String command = "draw";
    private Shape selectedShape = null;

    public ExamplePanel4(){
        setBackground(Color.white);
    }

    public void setCommand(String command){
        this.command = command;
    }

    public void paintComponent(Graphics g){
        // Draws any shapes that currently exist.
        super.paintComponent(g);
        for (Shape shape : shapeList)
            shape.draw(g);
    }

    public void mousePressed(int x, int y){
        /* Remembers the coordinates of the mouse.
           If command is "erase", search for selected
           shape and remove and repaint if found. */
        this.x = x;
        this.y = y;
        if (command.equals("erase") || command.equals("move"))
            for (Shape shape : shapeList)
                if (shape.containsPoint(x, y)){
                    if (command.equals("erase")){
                        shapeList.remove(shape);
                        repaint();
                    }
                    else
                        selectedShape = shape;
                    return;
                } 
    }

    public void mouseDragged(int x, int y){
        /* If a shape is selected, resets its position to
           the current mouse position and repaints.  */
        if (selectedShape != null){
            selectedShape.translate(x, y);
            repaint();
        }
    }
           
    public void mouseReleased(int x, int y){
        /* If command is "draw", creates a new oval, 
           adds it to the shape list, and repaints.
           If the command is "move", resets selectedShape. */
        if (command.equals("erase")) return;
        else if (command.equals("move")) selectedShape = null;
        else if ((x != this.x) && (y != this.y)){
            int w = x - this.x;
            int h = y - this.y;
            Color color = getRandomColor();
            Oval oval = new Oval(this.x, this.y, w, h, color);
            shapeList.add(oval);
            repaint();
        }
    }

    private Color getRandomColor(){
        int red = gen.nextInt(256);
        int green = gen.nextInt(256);
        int blue = gen.nextInt(256);
        return new Color(red, green, blue);
    }
}