/*
File: ListBoxDemo.java
Demonstrates the capabilities of scrolling list boxes.
*/

import BreezySwing.GBFrame;
import BreezySwing.IntegerField; 
import javax.swing.JButton;
import javax.swing.JLabel;
import javax.swing.JTextField;
import javax.swing.JList;
import javax.swing.DefaultListModel;

public class ListBoxDemo extends GBFrame{

    private JList listBox = addList(                    1,1,1,4);
    private JLabel inputLbl = addLabel("Input",         1,2,1,1);
    private JTextField inputFld = addTextField("",      1,3,1,1);
    private JLabel indexLbl = addLabel("Current index", 2,2,1,1);
    private IntegerField indexFld = addIntegerField(-1, 2,3,1,1);
    private JLabel itemLbl = addLabel("Current item",   3,2,1,1);
    private JTextField itemFld = addTextField("",       3,3,1,1);
    private JButton addBtn = addButton("Add",           4,2,1,1);
    private JButton removeBtn = addButton("Remove",     4,3,1,1);

    // The model for the list box.
    private DefaultListModel model = (DefaultListModel)listBox.getModel();

    public ListBoxDemo(){
        // Add some items to the list model and select the first one
        model.addElement("Apple");
        model.addElement("Banana");
        model.addElement("Cherry");
        model.addElement("Orange");
        listBox.setSelectedIndex(0);
        itemFld.setText("Apple");
        indexFld.setNumber(0);
        indexFld.setEditable(false);
        itemFld.setEditable(false);
        setTitle("List Box Demo");
        setSize(300, 150);
        setVisible(true);
    }

    public void listItemSelected (JList listObj){ 
        int index = listBox.getSelectedIndex();
        indexFld.setNumber(index);
        String item = (String)listBox.getSelectedValue();
        itemFld.setText(item);
    }

    public void buttonClicked(JButton button){
        if (button == addBtn)
            addItem();
        else
            removeItem();
    }

    private void addItem(){
       /* If an input is present, insert it before the selected
          item in the list box.  The new item becomes current.
          If the item added is first one, select it and enable the
          Remove button. */
        String item = inputFld.getText();
        if (item.equals("")) 
            return;
        int index = indexFld.getNumber();
        if (index == -1){ 
            model.addElement(item);
            index = 0;
            indexFld.setNumber(index);
            removeBtn.setEnabled(true);
        }
        else
            model.insertElementAt(item, index);  
        listBox.setSelectedIndex(index);
        inputFld.setText("");
        itemFld.setText(item);
    }

    private void removeItem(){
       /* If there are items in the list, remove the selected item,
          select the previous one, and update the fields.  If there was
          no previous item, select the next one.  If the last item is
          removed, disable the remove button.item from the list model and
          updates the view. */
        int index = indexFld.getNumber();
        model.remove(index);
        if (model.size() == 0){
            itemFld.setText("");
            indexFld.setNumber(-1);
            removeBtn.setEnabled(false);
        }else{
            if (index > 0) index -= 1;
            indexFld.setNumber(index);
            itemFld.setText((String)model.getElementAt(index));
            listBox.setSelectedIndex(index);
        }
    }

    public static void main(String[] args){
        GBFrame theGUI = new ListBoxDemo();
    }
}