/*
File: FileDialogDemo.java
Illustrates the use of file dialogs.
*/

import BreezySwing.GBFrame;
import javax.swing.JLabel; 
import javax.swing.JMenuItem;
import javax.swing.JTextArea;
import javax.swing.JFileChooser;
import javax.swing.filechooser.FileNameExtensionFilter;
import java.io.File;
import java.io.PrintWriter;
import java.io.IOException;
import java.util.Scanner;

public class FileDialogDemo extends GBFrame{

    private JMenuItem newMI = addMenuItem("File", "New");
    private JMenuItem openMI = addMenuItem("File", "Open");
    private JMenuItem saveAsMI = addMenuItem("File", "Save As");
    private JTextArea inputArea = addTextArea("", 1,1,1,1);
    private JFileChooser fileChooser = new JFileChooser();

    public FileDialogDemo(){
        FileNameExtensionFilter filter = 
            new FileNameExtensionFilter(
                ".txt or .java files", "txt", "java");
        fileChooser.setFileFilter(filter);
        setTitle("File Dialog Demo");
        setSize(500, 300);
        setVisible(true);
    }

    public void menuItemSelected(JMenuItem menuItem){
        if (menuItem == newMI){
            setTitle("File Dialog Demo");
            inputArea.setText("");
        }
        else if (menuItem == openMI)
            openFile();
        else if (menuItem == saveAsMI)
            saveFileAs();
    }

    private void openFile(){
        int returnVal = fileChooser.showOpenDialog(this);
        if (returnVal == JFileChooser.APPROVE_OPTION){
            inputArea.setText("");
            File inputFile = fileChooser.getSelectedFile();
            setTitle(inputFile.getPath());
            try{
                Scanner reader = new Scanner(inputFile);
                while (reader.hasNextLine())
                inputArea.append(reader.nextLine() + "\n");
                reader.close();
            }catch(IOException e){}             
        }
    }

    private void saveFileAs(){
        int returnVal = fileChooser.showSaveDialog(this);
        if (returnVal == JFileChooser.APPROVE_OPTION){
            File outputFile = fileChooser.getSelectedFile();
            setTitle(outputFile.getPath());
            try{
                PrintWriter writer = new PrintWriter(outputFile);
                writer.print(inputArea.getText());
                writer.close();
            }catch(IOException e){}
        }
    }

    public static void main(String[] args){
        GBFrame theGUI = new FileDialogDemo();
    }
}