/*
File: SongBrowser.java
A view of a song database.
*/

import BreezySwing.GBFrame;
import javax.swing.JMenuItem; 
import javax.swing.JList;
import javax.swing.JTextArea;
import javax.swing.DefaultListModel;
import javax.swing.JFileChooser;
import javax.swing.filechooser.FileNameExtensionFilter;

public class SongBrowser extends GBFrame{

    private JMenuItem openMI = addMenuItem("File", "Open");
    private JMenuItem saveMI = addMenuItem("File", "Save");
    private JMenuItem saveAsMI = addMenuItem("File", "Save As...");
    private JMenuItem removeMI = addMenuItem("Edit", "Remove");
    private JList songList = addList(             1,1,1,1);
    private JTextArea songArea = addTextArea("", 1,2,1,1);
    private JFileChooser fileChooser = new JFileChooser();

    // The model for the list box.
    private DefaultListModel listModel = (DefaultListModel)songList.getModel();

    private SongDatabase database;

    public SongBrowser(String fileName){
        // Sets up the initial view
        FileNameExtensionFilter filter = 
            new FileNameExtensionFilter(
                ".dat files", "dat");
        fileChooser.setFileFilter(filter);
        this.database = new SongDatabase(fileName);
        if (!fileName.equals("")){
            for (String title : this.database.getTitles())
                listModel.addElement(title);
            songList.setSelectedIndex(0);
            listItemSelected(songList);
        }else{
            saveMI.setEnabled(false);
            removeMI.setEnabled(false);
        }
        songArea.setEditable(false);  
        setTitle("Song Database");
        setSize(300, 200);
        setVisible(true);
    }

    public void listItemSelected (JList listObj){ 
        String selectedTitle = (String)songList.getSelectedValue();
        songArea.setText(database.get(selectedTitle).toString());
    }

    public void menuItemSelected(JMenuItem menuItem){
        if (menuItem == openMI)
            openFile();
        else if (menuItem == saveMI)
            saveFile();
        else if (menuItem == saveAsMI)
            saveFileAs();
        else if (menuItem == removeMI)
            removeSong();
    }

    public void openFile(){
        /* Pops up an open file dialog.  Updates the view if
           a file is opened. */
        int returnVal = fileChooser.showOpenDialog(this);
        if (returnVal == JFileChooser.APPROVE_OPTION){
            songArea.setText("");
            String fileName = fileChooser.getSelectedFile().getName();
            database = new SongDatabase(fileName);
            listModel.clear();
            for (String title : database.getTitles())
                listModel.addElement(title);
            songList.setSelectedIndex(0);
            listItemSelected(songList);
            saveMI.setEnabled(true);
            removeMI.setEnabled(true);
        }
    }

    public void saveFile(){
        database.save("");
    }

    public void saveFileAs(){
        // Pops up a dialog to save the database to a file.
        int returnVal = fileChooser.showSaveDialog(this);
        if (returnVal == JFileChooser.APPROVE_OPTION){
            database.save(fileChooser.getSelectedFile().getName());
            saveMI.setEnabled(true);
        }
    }

    private void removeSong(){
       /* If there are titles in the list, remove the selected title,
          select the previous one, and update the view.  If there was
          no previous title, select the next one.  If the last title is
          removed, disable the remove menu item. */
        int index = songList.getSelectedIndex();
        listModel.remove(index);
        if (listModel.size() == 0){
            songArea.setText("");
            removeMI.setEnabled(false);
        }else{
            if (index > 0) index -= 1;
            songList.setSelectedIndex(index);
            listItemSelected(songList);
        }
    }

    public static void main(String[] args){
        GBFrame theGUI = new SongBrowser("songs.dat");
    }
}