/*
File: SongDatabase.java
Represents a database of songs
*/

import java.io.Serializable;
import java.io.FileInputStream;
import java.io.ObjectInputStream;
import java.io.FileOutputStream;
import java.io.ObjectOutputStream;
import java.io.IOException;
import java.util.SortedMap;
import java.util.TreeMap;
import java.util.List;
import java.util.ArrayList;

public class SongDatabase implements Serializable{
    /* Models a song database. */

    private SortedMap<String, Song> items;
    private String fileName;

    public SongDatabase(String fileName){
        /* Sets up the model.  Loads the model with 
           songs if there is a file name. */
        items = new TreeMap<String, Song>();
        this.fileName = fileName;
        if (!fileName.equals("")){
            try{
                ObjectInputStream stream = 
                    new ObjectInputStream(
                        new FileInputStream(this.fileName));
                while (true){
                    Song song = (Song)stream.readObject();
                    items.put(song.title, song);
                }
            }catch(IOException e){
            }catch(ClassNotFoundException e) {}
        }
    }

    public void save(String fileName ){
        // Saves the database to a file.
        if (!fileName.equals(""))
            this.fileName = fileName;
        else if (this.fileName == "") return;
        try{
            ObjectOutputStream stream = 
                new ObjectOutputStream(
                    new FileOutputStream(this.fileName));
            for (String key : items.keySet())
                stream.writeObject(items.get(key));
            stream.flush();
            stream.close();
        }catch(IOException e){}
    }

    public Song get(String title){
        /* Returns the cd with the given title, or null if
           the title does not exist. */
        return items.get(title);
    }

    public void put(String title, Song song){
        // Adds or replaces the cd at the given title.
        items.put(title, song);
    }

    public Song remove(String title){
        /* Removes and returns the cd at the given title,
        or returns null if the title does not exist. */
        return items.remove(title);
    }

    public List<String> getTitles(){
        // Returns a sorted list of titles.
        List<String> titles = new ArrayList<String>(items.keySet());
        return titles;
    }

    public String toString(){
        // Returns the string rep of the database.
        String result = "";
        for (String key : items.keySet())
            result += items.get(key).toString() + "\n";
        return result;
    }

    public static SongDatabase createDatabase(){
        /* Creates a database, adds songs to it,
           and returns it. */
        SongDatabase database = new SongDatabase("");
        Song song = new Song("Let It Be", "The Beatles", 0.99);
        database.put(song.title, song);
        song = new Song("Gimme Shelter", "The Rolling Stones", 01.29);
        database.put(song.title, song);
        song = new Song("Kashmir", "Led Zepplin", 1.29);
        database.put(song.title, song);
        song = new Song("Der Kommissar", "Falco", 0.99);
        database.put(song.title, song);
        return database;
    }
}