/*
File: TextAreaDemo.java

Compute an investment report.

1. The inputs are
       starting investment amount 
       number of years
       interest rate (an integer percent)

2. The report is displayed in tabular form with a header.

3. Computations and outputs:
       for each year
          compute the interest and add it to the investment
          print a formatted row of results for that year
       
4. The total investment and interest earned are also displayed.
*/

import BreezySwing.GBFrame; 
import javax.swing.JLabel;
import javax.swing.JButton;
import BreezySwing.IntegerField;
import BreezySwing.DoubleField;
import javax.swing.JTextArea;

public class TextAreaDemo extends GBFrame{

    private JLabel balanceLbl = addLabel("Initial amount",  1,1,1,1);
    private JLabel yearsLbl = addLabel("Number of years",   2,1,1,1);
    private JLabel rateLbl = addLabel("Interest rate in %", 3,1,1,1);
    private DoubleField balanceFld = addDoubleField(0.0,    1,2,1,1);
    private IntegerField yearsFld = addIntegerField(0,      2,2,1,1);
    private IntegerField rateFld = addIntegerField(0,       3,2,1,1);
    private JButton convertBtn = addButton("Compute",       4,1,2,1);
    private JTextArea reportArea = addTextArea("",          5,1,2,5);

    public TextAreaDemo(){
        reportArea.setEditable(false);
        setTitle("Text Area Demo");
        setSize(400, 350);
        setVisible(true);
    }

    public void buttonClicked(JButton button){
        // Obtain the inputs.
        double balance = balanceFld.getNumber();
        double rate = rateFld.getNumber() / 100.0;
        int years = yearsFld.getNumber();
        if (balance == 0.0 || rate == 0 || years == 0)
            return;

        // Set the header for the table.
        String report = String.format("%4s%18s%10s%16s\n",
                                      "Year", "Starting balance",
                                      "Interest", "Ending balance");

        // Compute and append the results for each year
        double totalInterest = 0.0;
        for (int year = 1; year <= years; year++){
            double interest = balance * rate;
            double endBalance = balance + interest;
            report += String.format("%4d%18.2f%10.2f%16.2f\n",
                                    year, balance, interest, 
                                    endBalance);
            balance = endBalance;
            totalInterest += interest;
        }

        // Append the totals for the period and output them.
        report += String.format("Ending balance: $%1.2f\n", balance);
        report += String.format("Total interest earned: $%1.2f\n", totalInterest);
        reportArea.setText(report);
    }

    public static void main(String[] args){
        GBFrame theGUI = new TextAreaDemo();
    }
}